@@ -200,18 +200,9 @@ func showBuildLog(dir, tgt string, buildLogRec map[string][]string, depth int) e
 		return w.Flush()
 	}
 	defer fd.Close()
-	fdDep, err := os.Open(path.Join(dirNormalized, RedoDir, tgtNormalized+DepSuffix))
-	if err != nil {
-		return err
-	}
-	depInfo, err := depRead(fdDep)
-	fdDep.Close()
-	if err != nil {
-		return err
-	}
-	subs := make([]*BuildLogJob, 0, len(depInfo.ifchanges))
-	for _, dep := range depInfo.ifchanges {
-		subDir, subTgt := cwdAndTgt(path.Join(dirNormalized, dep["Target"]))
+	subs := make([]*BuildLogJob, 0, len(buildLogRec["Ifchange"]))
+	for _, dep := range buildLogRec["Ifchange"] {
+		subDir, subTgt := cwdAndTgt(path.Join(dirNormalized, dep))
 		if subDir == dirNormalized && subTgt == tgtNormalized {
 			continue
 		}
@@ -238,7 +229,7 @@ func showBuildLog(dir, tgt string, buildLogRec map[string][]string, depth int) e
 		}
 		subs = append(subs, &BuildLogJob{
 			dir:      dirNormalized,
-			tgt:      dep["Target"],
+			tgt:      dep,
 			started:  started,
 			exitCode: exitCode,
 			rec:      rec,
