@@ -65,7 +65,8 @@ func redoDirClean(root, what string) error {
 			pth = cwdMustRel(root, fi.Name())
 			switch what {
 			case CleanupLog:
-				if strings.HasSuffix(fi.Name(), LogSuffix) {
+				if strings.HasSuffix(fi.Name(), LogSuffix) ||
+					strings.HasSuffix(fi.Name(), LogSuffix+DepSuffix) {
 					fmt.Println(pth)
 					if !*DryRun {
 						if err = os.Remove(pth); err != nil {
