@@ -489,7 +489,7 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 					w := bufio.NewWriter(fdStderr)
 
 					var depInfo *DepInfo
-					fdDep, err = os.Open(fdDep.Name())
+					fdDep, err := os.Open(fdDepPath)
 					if err != nil {
 						goto Err
 					}
@@ -671,7 +671,8 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 				goto Finish
 			}
 		}
-		err = os.Rename(fdDep.Name(), path.Join(redoDir, tgt+DepSuffix))
+		fdDepPath = path.Join(redoDir, tgt+DepSuffix)
+		err = os.Rename(fdDep.Name(), fdDepPath)
 		if err != nil {
 			goto Finish
 		}
